package me.lensfrex.vegetables.resopnse;

/**
 * 统一的返回数据结构，含有字段code, message, data
 *
 * @param <T> data的类型
 */
public class UnityResponse<T> {
    /**
     * 返回码。其值为ResultCode中定义的常量
     */
    private int code;
    /**
     * 返回的结果信息
     */
    private String message;
    /**
     * 请求的数据，其类型为声明返回类时指定的类型
     */
    private T data;

    public UnityResponse(int code, String message, T data) {
        this.code = code;
        this.message = message;
        this.data = data;
    }

    public UnityResponse() {
        this.code = ResultCode.EMPTY_DATA;
        this.message = "数据未初始化";
        this.data = null;
    }

    public int getCode() {
        return code;
    }

    public void setCode(int code) {
        this.code = code;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public T getData() {
        return data;
    }

    public void setData(T data) {
        this.data = data;
    }

    @Override
    public String toString() {
        return "UnityResponse{" +
                "code=" + code +
                ", message='" + message + '\'' +
                ", data=" + data +
                '}';
    }

    /**
     * 状态码的常量
     */
    static class ResultCode {
        /**
         * 请求成功
         */
        public static final int SUCCESS = 200;
        /**
         * 数据是空的
         */
        public static final int EMPTY_DATA = 0;
        /**
         * 请求的分页页码超过最大值
         */
        public static final int PAGE_OUT_OF_MAX = 100;
        /**
         * 请求的分页参数有误
         */
        public static final int PAGE_PARAM_WORN = 101;
        /**
         * 未知错误
         */
        public static final int UNKNOWN_ERROR = 503;
    }
}
